@@ -6,6 +6,8 @@ function(data) {
   result = cumsum(freq)
   result = c(start=1, 1+result)
   names(result) = c(names(result)[-1], "end")
+  # get rid of trailing white space
+  names(result) = gsub("[[:space:]]+$", "", names(result))
   return(result)
 }
 
